Module context

Module context 

Global Plexus RPC context for sharing state with activations

This module provides a thread-safe way to share the Plexus RPC server hash with all activations. The hash is set once during hub initialization and can be read by any activation when creating stream items.

Structs

PlexusContext
Shared Plexus RPC context accessible to all activations