Module plexus

Module plexus 

DynamicHub - the central routing layer for activations

DynamicHub IS an activation that also serves as the registry for other activations. It implements the Plexus RPC protocol for routing and introspection. It uses hub-macro for its methods, with the call method using the streaming pattern to forward responses from routed methods.

Structs

ActivationInfo
ChildHashes
Hash information for a child plugin
DynamicHub
DynamicHub - an activation that routes to dynamically registered child activations
PluginEntry
Entry in the activation registry
PluginHashes
Lightweight hash information for cache validation
PluginRegistry
Registry mapping activation UUIDs to their current paths
PluginRegistrySnapshot
Read-only snapshot of the activation registry

Enums

DynamicHubMethod
Auto-generated method enum for schema extraction
HashEvent
PlexusError
SchemaEvent
Event for schema() RPC method - returns plugin schema
TransportErrorKind

Traits

Activation
ChildRouter
Trait for activations that can route to child activations
DynamicHubRpcServer
Server trait implementation for the DynamicHubRpc RPC API.

Functions

route_to_child
Route a method call to a child activation