pub struct ChildHashes {
pub namespace: String,
pub hash: String,
}Fields
namespace: Stringhash: StringTrait Implementations
Sourceimpl Clone for ChildHashes
impl Clone for ChildHashes
Sourcefn clone(&self) -> ChildHashes
fn clone(&self) -> ChildHashes
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChildHashes
impl Debug for ChildHashes
Sourceimpl<'de> Deserialize<'de> for ChildHashes
impl<'de> Deserialize<'de> for ChildHashes
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChildHashes
impl JsonSchema for ChildHashes
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChildHashes
impl RefUnwindSafe for ChildHashes
impl Send for ChildHashes
impl Sync for ChildHashes
impl Unpin for ChildHashes
impl UnsafeUnpin for ChildHashes
impl UnwindSafe for ChildHashes