Example DynamicHub builder
This module provides an example of how to build a DynamicHub instance. Real applications should create their own builder with their specific activations.
Functions
- build_
example_ hub - Build an example hub with minimal activations