DynamicHub - the central routing layer for activations
DynamicHub IS an activation that also serves as the registry for other activations.
It implements the Plexus RPC protocol for routing and introspection.
It uses hub-macro for its methods, with the call method using the streaming
pattern to forward responses from routed methods.
Structs
- Activation
Info - Child
Hashes - Hash information for a child plugin
- Dynamic
Hub - DynamicHub - an activation that routes to dynamically registered child activations
- Plugin
Entry - Entry in the activation registry
- Plugin
Hashes - Lightweight hash information for cache validation
- Plugin
Registry - Registry mapping activation UUIDs to their current paths
- Plugin
Registry Snapshot - Read-only snapshot of the activation registry
Enums
- Dynamic
HubMethod - Auto-generated method enum for schema extraction
- Hash
Event - Plexus
Error - Schema
Event - Event for schema() RPC method - returns plugin schema
- Transport
Error Kind
Traits
- Activation
- Child
Router - Trait for activations that can route to child activations
- Dynamic
HubRpc Server - Server trait implementation for the
DynamicHubRpcRPC API.
Functions
- route_
to_ child - Route a method call to a child activation