pub enum DynamicHubMethod {
Call {
method: String,
params: Option<Value>,
},
Hash,
Hashes,
}Expand description
Auto-generated method enum for schema extraction
Variants
Call
Route a call to a registered activation
Hash
Get Plexus RPC server configuration hash (from the recursive schema) This hash changes whenever any method or child activation changes. It’s computed from the method hashes rolled up through the schema tree.
Hashes
Get plugin hashes for cache validation (lightweight alternative to full schema)
Implementations
Sourceimpl DynamicHubMethod
impl DynamicHubMethod
pub fn all_method_names() -> &'static [&'static str]
Sourceimpl DynamicHubMethod
impl DynamicHubMethod
Sourcepub fn method_schemas() -> Vec<MethodSchema>
pub fn method_schemas() -> Vec<MethodSchema>
Get per-method schema info including params, return types, and content hashes
Note: This method has O(1) schema lookup cost after first call due to caching.